summaryrefslogtreecommitdiff
path: root/lib/gnutls_anon_cred.c
diff options
context:
space:
mode:
authorNikos Mavrogiannopoulos <nmav@gnutls.org>2003-11-30 06:36:03 +0000
committerNikos Mavrogiannopoulos <nmav@gnutls.org>2003-11-30 06:36:03 +0000
commit07053a732434bf4cadabb7fdf0e532348b5984a6 (patch)
tree48946391d8433944f706f81938e23dad1bb576da /lib/gnutls_anon_cred.c
parent557db5286e8587865927ab9d16f3e2d6d2460e94 (diff)
downloadgnutls-07053a732434bf4cadabb7fdf0e532348b5984a6.tar.gz
several corrections in the documentation.
Diffstat (limited to 'lib/gnutls_anon_cred.c')
-rw-r--r--lib/gnutls_anon_cred.c18
1 files changed, 7 insertions, 11 deletions
diff --git a/lib/gnutls_anon_cred.c b/lib/gnutls_anon_cred.c
index a52c64c737..578aef62af 100644
--- a/lib/gnutls_anon_cred.c
+++ b/lib/gnutls_anon_cred.c
@@ -30,15 +30,14 @@
#include "gnutls_num.h"
#include "gnutls_mpi.h"
-static int anon_tmp;
+static const int anon_dummy;
/**
* gnutls_anon_free_server_credentials - Used to free an allocated gnutls_anon_server_credentials structure
* @sc: is an &gnutls_anon_server_credentials structure.
*
* This structure is complex enough to manipulate directly thus
- * this helper function is provided in order to free (deallocate)
- * the structure.
+ * this helper function is provided in order to free (deallocate) it.
**/
void gnutls_anon_free_server_credentials( gnutls_anon_server_credentials sc) {
@@ -50,8 +49,7 @@ void gnutls_anon_free_server_credentials( gnutls_anon_server_credentials sc) {
* @sc: is a pointer to an &gnutls_anon_server_credentials structure.
*
* This structure is complex enough to manipulate directly thus
- * this helper function is provided in order to allocate
- * the structure.
+ * this helper function is provided in order to allocate it.
**/
int gnutls_anon_allocate_server_credentials( gnutls_anon_server_credentials *sc) {
@@ -66,8 +64,7 @@ int gnutls_anon_allocate_server_credentials( gnutls_anon_server_credentials *sc)
* @sc: is an &gnutls_anon_client_credentials structure.
*
* This structure is complex enough to manipulate directly thus
- * this helper function is provided in order to free (deallocate)
- * the structure.
+ * this helper function is provided in order to free (deallocate) it.
**/
void gnutls_anon_free_client_credentials( gnutls_anon_client_credentials sc) {
}
@@ -77,15 +74,14 @@ void gnutls_anon_free_client_credentials( gnutls_anon_client_credentials sc) {
* @sc: is a pointer to an &gnutls_anon_client_credentials structure.
*
* This structure is complex enough to manipulate directly thus
- * this helper function is provided in order to allocate
- * the structure.
+ * this helper function is provided in order to allocate it.
**/
int gnutls_anon_allocate_client_credentials( gnutls_anon_client_credentials *sc)
{
/* anon_tmp is only there for *sc not to be null.
* it is not used at all;
*/
- *sc = (void*) &anon_tmp;
+ *sc = (void*) &anon_dummy;
return 0;
}
@@ -77,15 +74,14 @@ void gnutls_anon_free_client_credentials( gnutls_anon_client_credentials sc) {
int gnutls_anon_allocate_client_credentials( gnutls_anon_client_credentials *sc)
{
- /* anon_tmp is only there for *sc not to be null.
+ /* anon_dummy is only there for *sc not to be null.
* it is not used at all;
*/